#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
//#include <ESP8266mDNS.h>
#include <OneWire.h>
#include <DallasTemperature.h>
#include <LiquidCrystal_I2C.h>
LiquidCrystal_I2C lcd(0x27, 16, 2);

// Data wire is plugged into port 2 on the Arduino
#define ONE_WIRE_BUS 2
// Setup a oneWire instance to communicate with any OneWire devices (not just Maxim/Dallas temperature ICs)
OneWire oneWire(ONE_WIRE_BUS);
// Pass our oneWire reference to Dallas Temperature. 
DallasTemperature sensors(&oneWire);

const char* ssid = "SSID";
const char* password = "heslo";

char temperatureCString[7];
char temperatureFString[7];

// Web Server on port 80
WiFiServer server(80);

int ThermistorPin = A0;
int Vo;
float R1 = 18550;
float logR2, R2, Tc, T;
char TcF[10];
float c1 = 1.009249522e-03, c2 = 2.378405444e-04, c3 = 2.019202697e-07;


void analog() {

  Vo = analogRead(ThermistorPin);
  R2 = R1 * (1000.0 / (float)Vo - 1.0);
  logR2 = log(R2);
  T = (1.0 / (c1 + c2*logR2 + c3*logR2*logR2*logR2));
  Tc = T - 273.15;

  lcd.print("ex:"); 
  dtostrf(Tc,2, 1, TcF);
  lcd.print(TcF);
  lcd.print((char)0xDF);
  lcd.println("C ");   
}

// only runs once on boot
void setup() {
  // Initializing serial port for debugging purposes
  //Serial.begin(115200);
  // delay(10);

  // initialize the LCD
  lcd.init();

  // Turn on the blacklight and print a message.
  lcd.backlight();

  sensors.begin(); // IC Default 9 bit. If you have troubles consider upping it 12. Ups the delay giving the IC more time to process the temperature measurement
  
  // Connecting to WiFi network
  //Serial.println();
  //Serial.print("Connecting to ");
  //Serial.println(ssid);
  WiFi.mode(WIFI_STA);
  
  WiFi.begin(ssid, password);
  lcd.setCursor(0, 0);
  while(WiFi.status() != WL_CONNECTED){
    delay(1000);
    lcd.print(".");
  }
  if (WiFi.status() == WL_CONNECTED) {
                lcd.setCursor(0, 0);
      lcd.println("WiFi connected ");
                lcd.setCursor(0, 1);
      lcd.printf(WiFi.hostname().c_str());
  }
  delay(5000);
  // Starting the web server
  server.begin();
 }

void getTemperature() {
  float tempC;
  float tempF;
  do {
    sensors.requestTemperatures(); 
    tempC = sensors.getTempCByIndex(0);
    dtostrf(tempC+2, 2, 1, temperatureCString);
    tempF = sensors.getTempFByIndex(0);
    dtostrf(tempF, 3, 2, temperatureFString);
    delay(100);
  } while (tempC == 89.0 || tempC == (-127.0));
}


// runs over and over again
void loop() {
            lcd.setCursor(0, 0);
            getTemperature();
            lcd.print(temperatureCString);
  lcd.print((char)0xDF); 
  lcd.print("C ");
  analog();
  delay(500);
  

  // Listenning for new clients
  WiFiClient client = server.available();
  
  if (client) {
    Serial.println("New client");
    // bolean to locate when the http request ends
    boolean blank_line = true;
    while (client.connected()) {
      if (client.available()) {
        char c = client.read();
        
        if (c == '\n' && blank_line) {
            getTemperature();
            client.println("HTTP/1.1 200 OK");
            client.println("Content-Type: text/html");
            client.println("Connection: close");
            client.println();
            // your actual web page that displays temperature
            client.println("<!DOCTYPE HTML>");
            client.println("<html>");
            client.println("<head></head><body><meta http-equiv=\"refresh\" content=\"50\"><h1>ESP8266 - Temperature</h1><h3>Temperature in Celsius: ");
            client.println(temperatureCString);
            client.println("*C</h3><h3>Temperature out: ");
             client.println(TcF);
             client.println("*C</h3><h3>Temperature in Fahrenheit: ");
            client.println(temperatureFString);
            client.println("*F</h3></body></html>");  
            break;
        }
        
        if (c == '\n') {
          // when starts reading a new line
          blank_line = true;
        }
        else if (c != '\r') {
          // when finds a character on the current line
          blank_line = false;
        }
      }
    }  
    // closing the client connection
    delay(10);
    client.stop();
  }
  lcd.setCursor(0, 1);
  lcd.print(WiFi.localIP());
}   
